@@ -2,9 +2,11 @@ from .proto_utils import ProtoTemplate, ProtoDataset
 from .data_utils import SparkDataset
 from .protos.mas import annotation_pb2 as annotation_proto
 from .protos.mas import image_data_pb2 as image_proto
+from .protos.mas import lyftbag_pb2 as lyftbag_proto
 from .aws_utils import FireSparkAWS as S3
 from .torch_utils import TorchLoaderBase as torch_loader
 from .numpy_utils import NumpyLoaderBase as np_loader
 from .tensorflow_utils import TFLoaderBase as tf_loader
+from .lyftbag_utils import CamLoader
 
-__version__ = '0.0.22'
\ No newline at end of file
+__version__ = '0.0.23'
\ No newline at end of file
