@@ -43,7 +43,7 @@ class SparkDataset(object):
 			'workspace' : "/tmp/mas/",
 			'n_records' : 1000,
 			'core' : 2,
-			'schema' : schemas.MasSchema,
+			'schema' : schemas.MasDetSchema,
 			's3profile' : "magna_data",
 			'label_fn' : None}
 		self.jc.update(job)
@@ -117,7 +117,7 @@ class SparkDataset(object):
 	def prepare_label(annotation):
 		label = []
 		for obj in annotation.objects:
-			label.append((obj.oclass, obj.cbox.x, obj.cbox.y, obj.cbox.w, obj.cbox.h))
+			label.append((obj.cbox.x, obj.cbox.y, obj.cbox.w, obj.cbox.h, obj.oclass))
 		return np.array(label)
 
 	def _row_generator(self, pd):
@@ -172,7 +172,7 @@ class SparkDataset(object):
 				self.spark.createDataFrame(sql_row, self.jc['schema'].as_spark_schema()) \
 					.coalesce(5).write.mode('append').parquet(parquet_url)
 			tot_proc += len(raw_proto_list)
-			progress_bar += progress_bar
+			progress_bar += "-"
 			print(progress_bar)
 		print("///: totally added {} examples to parquet dataset!".format(tot_proc))
 		
@@ -182,8 +182,8 @@ class SparkDataset(object):
 			for parquet in tqdm.tqdm(parquet_records):
 				local_key = os.path.join(self._parquet_work, parquet)
 				target_key = os.path.join(self._s3_key, parquet)
-				self.aws.upload_file(self._bucket_dst, local_key, target_key)
-			os.remove(local_key)
+				st = self.aws.upload_file(self._bucket_dst, local_key, target_key)
+				if st: os.remove(local_key)
 		else:
 			print("///: sync to destination ...")
 			if self.jc['storage_url']:
