@@ -31,6 +31,7 @@ import os
 from .proto_utils import ProtoDataset
 from .protos.mas import annotation_pb2 as annotation_proto
 from .protos.mas import image_data_pb2 as image_proto
+from .protos.mas import labels_pb2 as label_proto 
 
 
 class DowntownDataset(ProtoDataset):
@@ -42,6 +43,13 @@ class DowntownDataset(ProtoDataset):
 						 data_source=data_source,
 						 data_storage=data_storage,
 						 num_records=num_records)
+		self.catetory_map = {
+				0: label_proto.PCP_L_PEDESTRIAN,
+				1: label_proto.PCP_L_BICYCLE,
+				2: label_proto.PCP_L_CAR,
+				3: label_proto.PCP_L_BUS,
+				4: label_proto.PCP_L_TRUCK
+		    }
 	
 	def _example_record(self, f):
 		""" Method for providing one downtown dataset example record
@@ -70,7 +78,7 @@ class DowntownDataset(ProtoDataset):
 		obstacles = []
 		for line in record[2]:
 			a = line.rstrip().split(" ")
-			obstacles.append({"class": int(a[0]),
+			obstacles.append({"class": self.catetory_map[int(a[0])],
 				"bbx": (float(a[1]), float(a[2]), float(a[3]), float(a[4]))})
 		if not obstacles: return None
 
